@@ -126,7 +126,7 @@ class WinkPowerStripOutlet(WinkBinarySwitch):
         response = self.api_interface.get_device_state(self, id_override=self.parent_id())
         power_strip = response.get('data')
         if require_desired_state_fulfilled:
-            if not is_desired_state_reached(power_strip[0]):
+            if not is_desired_state_reached(power_strip[self.index]):
                 return
 
         power_strip_reading = power_strip.get('last_reading')
@@ -136,6 +136,22 @@ class WinkPowerStripOutlet(WinkBinarySwitch):
                 outlet['last_reading']['connection'] = power_strip_reading.get('connection')
                 self.json_state = outlet
 
+    def _update_state_from_response(self, response_json, require_desired_state_fulfilled=False):
+        """
+        :param response_json: the json obj returned from query
+        :return:
+        """
+        power_strip = response_json
+        power_strip_reading = power_strip.get('last_reading')
+        outlets = power_strip.get('outlets', power_strip)
+        for outlet in outlets:
+            if outlet.get('outlet_id') == str(self.device_id()):
+                outlet['last_reading']['connection'] = power_strip_reading.get('connection')
+                self.json_state = outlet
+
+    def pubnub_update(self, json_response):
+        self._update_state_from_response(json_response)
+
     def index(self):
         return self.json_state.get('outlet_index', None)
 
@@ -159,7 +175,8 @@ class WinkPowerStripOutlet(WinkBinarySwitch):
             values = {"outlets": [{}, {"desired_state": {"powered": state}}]}
 
         response = self.api_interface.set_device_state(self, values, id_override=self.parent_id())
-        self._update_state_from_response(response)
+        power_strip = response.get('data')
+        self._update_state_from_response(power_strip)
 
         self._last_call = (time.time(), state)
 
